@@ -30,15 +30,18 @@ package Hardware::UPS::Perl::Driver;
 #==============================================================================
 # Entries for Revision Control:
 #==============================================================================
-# Revision        : $Revision: 1.7 $
+# Revision        : $Revision: 1.8 $
 # Author          : $Author: creile $
-# Last Modified On: $Date: 2007/04/14 09:37:26 $
+# Last Modified On: $Date: 2007/04/17 19:45:29 $
 # Status          : $State: Exp $
 #------------------------------------------------------------------------------
 # Modifications   :
 #------------------------------------------------------------------------------
 #
 #   $Log: Driver.pm,v $
+#   Revision 1.8  2007/04/17 19:45:29  creile
+#   missing import Hardware::UPS::Perl::Logging added.
+#
 #   Revision 1.7  2007/04/14 09:37:26  creile
 #   documentation update.
 #
@@ -78,7 +81,7 @@ BEGIN {
     
     use vars qw($VERSION @ISA);
 
-    $VERSION = sprintf( "%d.%02d", q$Revision: 1.7 $ =~ /(\d+)\.(\d+)/ );
+    $VERSION = sprintf( "%d.%02d", q$Revision: 1.8 $ =~ /(\d+)\.(\d+)/ );
 
     @ISA     = qw();
 
@@ -94,6 +97,8 @@ BEGIN {
 #
 #   Hardware::UPS::Perl::General    - importing Hardware::UPS::Perl variables
 #                                     and functions for scripts
+#   Hardware::UPS::Perl::Logging    - importing Hardware::UPS::Perl methods
+#                                     dealing with logfiles
 #   Hardware::UPS::Perl::Utils      - importing Hardware::UPS::Perl utility
 #                                     functions for packages
 #
@@ -102,6 +107,7 @@ BEGIN {
 use Hardware::UPS::Perl::General qw(
     $UPSERROR
 );
+use Hardware::UPS::Perl::Logging;
 use Hardware::UPS::Perl::Utils qw(
     error
 );
